// package: 
// file: management/ManagementCompat.proto

/* tslint:disable */
/* eslint-disable */

import * as jspb from "google-protobuf";
import * as common_Common_pb from "../common/Common_pb";
import * as management_Management_pb from "../management/Management_pb";
