// package: 
// file: service-mesh-probe/service-mesh-compat.proto

/* tslint:disable */
/* eslint-disable */

import * as jspb from "google-protobuf";
import * as service_mesh_probe_service_mesh_pb from "../service-mesh-probe/service-mesh_pb";
