// package: 
// file: language-agent/MeterCompat.proto

/* tslint:disable */
/* eslint-disable */

import * as jspb from "google-protobuf";
import * as common_Common_pb from "../common/Common_pb";
import * as language_agent_Meter_pb from "../language-agent/Meter_pb";
