// package: 
// file: browser/BrowserPerfCompat.proto

/* tslint:disable */
/* eslint-disable */

import * as jspb from "google-protobuf";
import * as common_Common_pb from "../common/Common_pb";
import * as browser_BrowserPerf_pb from "../browser/BrowserPerf_pb";
