/*!
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import Protocol from '../../../agent/protocol/Protocol';
import HeartbeatClient from '../../../agent/protocol/grpc/clients/HeartbeatClient';
import TraceReportClient from '../../../agent/protocol/grpc/clients/TraceReportClient';

export default class GrpcProtocol implements Protocol {
  private readonly heartbeatClient: HeartbeatClient;
  private readonly traceReportClient: TraceReportClient;

  constructor() {
    this.heartbeatClient = new HeartbeatClient();
    this.traceReportClient = new TraceReportClient();
  }

  get isConnected(): boolean {
    return this.heartbeatClient.isConnected && this.traceReportClient.isConnected;
  }

  heartbeat(): this {
    this.heartbeatClient.start();
    return this;
  }

  report(): this {
    this.traceReportClient.start();
    return this;
  }

  flush(): Promise<any> | null {
    return this.traceReportClient.flush();
  }

  destroy(): void {
    // Clean up both clients to prevent memory leaks
    this.heartbeatClient.destroy?.();
    this.traceReportClient.destroy?.();
  }
}
