// package: skywalking.v3
// file: language-agent/ConfigurationDiscoveryService.proto

/* tslint:disable */
/* eslint-disable */

import * as jspb from "google-protobuf";
import * as common_Common_pb from "../common/Common_pb";

export class ConfigurationSyncRequest extends jspb.Message { 
    getService(): string;
    setService(value: string): ConfigurationSyncRequest;
    getUuid(): string;
    setUuid(value: string): ConfigurationSyncRequest;

    serializeBinary(): Uint8Array;
    toObject(includeInstance?: boolean): ConfigurationSyncRequest.AsObject;
    static toObject(includeInstance: boolean, msg: ConfigurationSyncRequest): ConfigurationSyncRequest.AsObject;
    static extensions: {[key: number]: jspb.ExtensionFieldInfo<jspb.Message>};
    static extensionsBinary: {[key: number]: jspb.ExtensionFieldBinaryInfo<jspb.Message>};
    static serializeBinaryToWriter(message: ConfigurationSyncRequest, writer: jspb.BinaryWriter): void;
    static deserializeBinary(bytes: Uint8Array): ConfigurationSyncRequest;
    static deserializeBinaryFromReader(message: ConfigurationSyncRequest, reader: jspb.BinaryReader): ConfigurationSyncRequest;
}

export namespace ConfigurationSyncRequest {
    export type AsObject = {
        service: string,
        uuid: string,
    }
}
