// package: skywalking.v3
// file: language-agent/Tracing.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "@grpc/grpc-js";
import * as language_agent_Tracing_pb from "../language-agent/Tracing_pb";
import * as common_Common_pb from "../common/Common_pb";

interface ITraceSegmentReportServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: ITraceSegmentReportServiceService_Icollect;
    collectInSync: ITraceSegmentReportServiceService_IcollectInSync;
}

interface ITraceSegmentReportServiceService_Icollect extends grpc.MethodDefinition<language_agent_Tracing_pb.SegmentObject, common_Common_pb.Commands> {
    path: "/skywalking.v3.TraceSegmentReportService/collect";
    requestStream: true;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_Tracing_pb.SegmentObject>;
    requestDeserialize: grpc.deserialize<language_agent_Tracing_pb.SegmentObject>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}
interface ITraceSegmentReportServiceService_IcollectInSync extends grpc.MethodDefinition<language_agent_Tracing_pb.SegmentCollection, common_Common_pb.Commands> {
    path: "/skywalking.v3.TraceSegmentReportService/collectInSync";
    requestStream: false;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_Tracing_pb.SegmentCollection>;
    requestDeserialize: grpc.deserialize<language_agent_Tracing_pb.SegmentCollection>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}

export const TraceSegmentReportServiceService: ITraceSegmentReportServiceService;

export interface ITraceSegmentReportServiceServer extends grpc.UntypedServiceImplementation {
    collect: grpc.handleClientStreamingCall<language_agent_Tracing_pb.SegmentObject, common_Common_pb.Commands>;
    collectInSync: grpc.handleUnaryCall<language_agent_Tracing_pb.SegmentCollection, common_Common_pb.Commands>;
}

export interface ITraceSegmentReportServiceClient {
    collect(callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    collectInSync(request: language_agent_Tracing_pb.SegmentCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collectInSync(request: language_agent_Tracing_pb.SegmentCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collectInSync(request: language_agent_Tracing_pb.SegmentCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

export class TraceSegmentReportServiceClient extends grpc.Client implements ITraceSegmentReportServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: Partial<grpc.ClientOptions>);
    public collect(callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    public collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    public collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    public collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientWritableStream<language_agent_Tracing_pb.SegmentObject>;
    public collectInSync(request: language_agent_Tracing_pb.SegmentCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collectInSync(request: language_agent_Tracing_pb.SegmentCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collectInSync(request: language_agent_Tracing_pb.SegmentCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}
